struct AbsoluteAxisSolver {
axis: Direction,
containing_size: Au,
padding_border_sum: Au,
computed_margin_start: AuOrAuto,
computed_margin_end: AuOrAuto,
computed_sizes: Sizes,
avoid_negative_margin_start: bool,
box_offsets: LogicalSides1D<AuOrAuto>,
static_position_rect_axis: RectAxis,
alignment: AlignFlags,
flip_anchor: bool,
is_table_or_replaced: bool,
}Fields
axis: Directioncontaining_size: Aupadding_border_sum: Aucomputed_margin_start: AuOrAutocomputed_margin_end: AuOrAutocomputed_sizes: Sizesavoid_negative_margin_start: boolbox_offsets: LogicalSides1D<AuOrAuto>static_position_rect_axis: RectAxisalignment: AlignFlagsflip_anchor: boolis_table_or_replaced: boolImplementations
Sourceimpl AbsoluteAxisSolver
impl AbsoluteAxisSolver
Sourcefn inset_sum(&self) -> Au
fn inset_sum(&self) -> Au
Returns the amount that we need to subtract from the containing block size in order to obtain the inset-modified containing block that we will use for sizing purposes. (Note that for alignment purposes, we may re-resolve auto insets to a different value.) https://drafts.csswg.org/css-position/#resolving-insets
Sourcefn available_space(&self) -> Au
fn available_space(&self) -> Au
Returns the size of the inset-modified containing block. https://drafts.csswg.org/css-position-3/#inset-modified-containing-block
fn automatic_size(&self) -> Size<Au>
fn stretch_size(&self) -> Au
fn solve_margins(&self, size: Au) -> LogicalSides1D<Au>
fn origin_for_margin_box( &self, size: Au, self_writing_mode: WritingMode, original_parent_writing_mode: WritingMode, containing_block_writing_mode: WritingMode, ) -> Au