LayoutRootLayoutInputs

Struct LayoutRootLayoutInputs 

pub(crate) struct LayoutRootLayoutInputs {
    fully_adjusted_static_position_rect: LogicalRect<Au>,
    resolved_alignment: LogicalVec2<AlignFlags>,
    containing_block_size: LogicalVec2<Au>,
    containing_block_style: Arc<ComputedValues>,
    original_parent_writing_mode: WritingMode,
}
These are the recorded layout inputs that were used when laying out an absolutely-positioned element. They can be re-used when the absolutely-positioned element is a viable layout root (no escaping fixed position elements, currently). The information here is enough to re-run layout for an absolute.

Fields

fully_adjusted_static_position_rect: LogicalRect<Au>

The fully adjusted static position rectangle used to lay out the absolute. This is adjusted by the containing blocks of all of the boxes that come between an absolute’s tree position and its layout containing block.

resolved_alignment: LogicalVec2<AlignFlags>

The resolved alignment to use when laying out the absolute. This comes from the original box.

containing_block_size: LogicalVec2<Au>

This is the containing block size of the absolute’s containing block. This is stored here because it’s easier to access than the parent box.

containing_block_style: Arc<ComputedValues>

This is the style of the containing block. This is stored here because it’s easier to access than the parent box.

original_parent_writing_mode: WritingMode

This is the writing mode of the absolute’s tree parent.

Implementations

Source

impl LayoutRootLayoutInputs

pub(crate) fn layout( &self, layout_context: &LayoutContext<'_>, context: &IndependentFormattingContext, shared_fragment: &ArcRefCell<HoistedSharedFragment>, ) -> Result<(), ()>

Re-run layout for the given inputs. This is used to run layout again at layout roots.